summaryrefslogtreecommitdiffstats
path: root/src/mesa/main/formats.c
diff options
context:
space:
mode:
authorAnuj Phogat <anuj.phogat@gmail.com>2016-02-10 16:41:23 -0800
committerAnuj Phogat <anuj.phogat@gmail.com>2016-05-03 03:43:17 -0700
commit6abb1b4984bba5560baccd53e68237ab86822ec0 (patch)
tree797a62da19ad6f1d9bf4070a55f3d1a68ed33af4 /src/mesa/main/formats.c
parentc4a0cd4662efe32e95c3f1e68b2f058b60bdcb52 (diff)
downloadexternal_mesa3d-6abb1b4984bba5560baccd53e68237ab86822ec0.zip
external_mesa3d-6abb1b4984bba5560baccd53e68237ab86822ec0.tar.gz
external_mesa3d-6abb1b4984bba5560baccd53e68237ab86822ec0.tar.bz2
mesa: Add block depth field in struct gl_format_info
This will be later required for 3D ASTC formats. Signed-off-by: Anuj Phogat <anuj.phogat@gmail.com> Reviewed-by: Brian Paul <brianp@vmware.com>
Diffstat (limited to 'src/mesa/main/formats.c')
-rw-r--r--src/mesa/main/formats.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mesa/main/formats.c b/src/mesa/main/formats.c
index 41d40a5..3d2349b 100644
--- a/src/mesa/main/formats.c
+++ b/src/mesa/main/formats.c
@@ -68,9 +68,9 @@ struct gl_format_info
bool IsSRGBFormat;
/**
* To describe compressed formats. If not compressed, Width=Height=1.
*/
- GLubyte BlockWidth, BlockHeight;
+ GLubyte BlockWidth, BlockHeight, BlockDepth;
GLubyte BytesPerBlock;
uint8_t Swizzle[4];
@@ -68,9 +68,9 @@ struct gl_format_info
bool IsSRGBFormat;
/**
- * To describe compressed formats. If not compressed, Width=Height=1.
+ * To describe compressed formats. If not compressed, Width=Height=Depth=1.
*/